@@ -1,3 +1,16 @@
+//! This crate (rustdb) implements a high-performance database written entirely in [Rust](https://www.rust-lang.org/).
+//!
+//! The SQL-like language is relatively minimal, and does not (currently) include features such as joins or views.
+//! Instead it has high performance SET .. FROM ... and FOR .. FROM statements to access database tables, 
+//! generally using an INDEX. 
+//!
+//! The complete language manual is available at run-time via the pre-configured (but optional) [init::INITSQL] 
+//! database initialisation string, which also includes many functions which illustrate how the language works, 
+//! including generic table browsing/editing, date and other functions.
+//!
+//! Read-only transactions run immediately and concurrently on a virtual read-only copy of the database, and cannot be blocked.
+//! Write transactions run sequentially (and should typically execute in around 100 micro-seconds). The [Storage] trait allows a variety of underlying storage, including [SimpleFileStorage], [MemFile] and [AtomicFile]. 
+
 //!# Interface
 //!
 //!The method [Database::run] (or alternatively [Database::run_timed]) is called to execute an SQL query.
@@ -37,7 +50,7 @@
 //!```
 //!
 //![See here](https://github.com/georgebarwood/RustDB/blob/main/examples/axumtest.rs) for more advanced example
-//! ( Axum webserver with ARGON hash function and query logging ).
+//! ( Axum webserver example using [AtomicFile], with ARGON hash function, read-only queries and query logging ).
 //!
 //!# Features
 //!
@@ -84,7 +97,7 @@ pub use crate::{
     gentrans::{GenTransaction, Part},
     init::INITSQL,
     pstore::{AccessPagedData, SharedPagedData},
-    stg::SimpleFileStorage,
+    stg::{MemFile,SimpleFileStorage},
     webtrans::WebTransaction,
 };
 
@@ -196,7 +209,7 @@ pub mod compile;
 mod compile;
 
 #[cfg(feature = "max")]
-/// [EvalEnv] : execution of instructions..
+/// [EvalEnv] : [Instruction] execution.
 pub mod exec;
 #[cfg(not(feature = "max"))]
 mod exec;
